pcx

Macro pcx 

macro_rules! pcx {
    ($($tokens:tt)*) => { ... };
}
Compiles every visible combination of conditional utility strings and selects one Style.

Selector expressions are evaluated once in source order by the internal procedural expansion.